==> haskell-pango-0.13.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.3.1
id: pango-0.13.3.1-1NPDZjGegnjKCvlUKSv18q
key: pango-0.13.3.1-1NPDZjGegnjKCvlUKSv18q
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Font
    Graphics.Rendering.Pango.Enums Graphics.Rendering.Pango.Context
    Graphics.Rendering.Pango.Layout Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Types Graphics.Rendering.Pango.BasicTypes
    Graphics.Rendering.Pango.Structs
    Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: fd3a53e3584f39e2c42ca559b2bb9a73
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pango-0.13.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/pango-0.13.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/pango-0.13.3.1
hs-libraries: HSpango-0.13.3.1-1NPDZjGegnjKCvlUKSv18q
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/libdrm
includes:
    hspango.h
depends:
    array-0.5.1.1 base-4.9.0.0 cairo-0.13.3.1-2aGPO8ZCviBEichAQxduNY
    containers-0.5.7.1 directory-1.2.6.2
    glib-0.13.4.1-EEQaey3pIjy8n9nCCarNfz
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pretty-1.1.3.3 process-1.4.2.0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.3.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.3.1
id: pango-0.13.3.1-Hzyqk4LyNVM5tRUzwKQeRg
key: pango-0.13.3.1-Hzyqk4LyNVM5tRUzwKQeRg
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Font
    Graphics.Rendering.Pango.Enums Graphics.Rendering.Pango.Context
    Graphics.Rendering.Pango.Layout Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Types Graphics.Rendering.Pango.BasicTypes
    Graphics.Rendering.Pango.Structs
    Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: 5d0790148a60aa38b8879ccb2ca55f01
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/pango-0.13.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/pango-0.13.3.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/pango-0.13.3.1
hs-libraries: HSpango-0.13.3.1-Hzyqk4LyNVM5tRUzwKQeRg
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/libdrm
includes:
    hspango.h
depends:
    array-0.5.1.1 base-4.9.1.0 cairo-0.13.3.1-Bs2ihMjNWEKCIr3suAC97g
    containers-0.5.7.1 directory-1.3.0.0
    glib-0.13.4.1-gX30WilRabHbki6rRO4oG
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pretty-1.1.3.3 process-1.4.3.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
